@@ -2,7 +2,6 @@
 
 import os
 import rsa
-import datetime as dt
 import hashlib as hash
 from Crypto.Cipher import AES
 from Crypto.Cipher import Blowfish
@@ -22,14 +21,25 @@ class Ciphers:
     """
 
 
-    def __init__(self, password=str, username=str) -> None:
+    def __init__(self, password=str) -> None:
         self.password = password
-        self.username = username
         self.marker  = b"E1m%nj2i$bhilj"
 
 
     # misc functions
 
+
+    def generate_symmetric_key(self, salt) -> 'tuple[bytes, bytes]':
+        "Method for generating keys. Will return tuple (key, salt) if salt is not provided."
+        if salt is None:
+            salt_ = os.urandom(32)
+            key = PBKDF2(self.password, salt_, dkLen=32)
+            return key, salt
+        else:
+            key = PBKDF2(self.password, salt, dkLen=32)
+            return key
+
+
     def sec_delete(self, file_path, random_fill = True, null_fill = True, passes = 35) -> int:
         if "/home/" not in file_path or "/." in file_path:
             return 1
@@ -134,25 +144,15 @@ class Ciphers:
         return encrypted_string
 
 
-    def RSA_decrypt_str(self, private_key, encrypted_str):
+    def RSA_decrypt_str(self, private_key, encrypted_str=str):
         "Method to decrypt a string with a RSA private key."
         decrypted_string = rsa.decrypt(encrypted_str, private_key).decode()
-        pass
+        return decrypted_string
 
 
         # AES functions
 
 
-    def generate_symmetric_key(self, salt) -> 'tuple[bytes, bytes]':
-        if salt is None:
-            salt_ = os.urandom(32)
-            key = PBKDF2(self.password, salt_, dkLen=32)
-            return key, salt
-        else:
-            key = PBKDF2(self.password, salt, dkLen=32)
-            return key
-
-
     def AESencrypt_file(self, path=str) -> int:
         """
         A method for encrypting a file/folder object.
@@ -168,17 +168,23 @@ class Ciphers:
             5: File is part of root filesystem and not part of ChromeOS.
             6: File encryption marker detected during encryption.
         """
-        return_code = self.check_path_validity(path, decrypting=False, type_="AES")
-        if return_code != 0:
-            return return_code
-        salt = os.urandom(32)
-        iv = os.urandom(16)
-        key = PBKDF2(self.password, salt, dkLen=32)
-        key_hash = hash.sha256(key); key_signature = key_hash.digest()
+        # encryption for single file
         if os.path.isfile(path) is True:
+            # checking if the file path is ok
+            return_code = self.check_path_validity(path, decrypting=False, type_="AES")
+            if return_code != 0:
+                return return_code
+                # generating a key and key signature
+            salt = os.urandom(32)
+            iv = os.urandom(16)
+            key_and_salt = self.generate_symmetric_key(salt=None)
+            key = key_and_salt[0]; salt = key_and_salt[1]
+            key_hash = hash.sha256(key); key_signature = key_hash.digest()
+            # getting the data and setting a cipher (using CFB to avoid padding.)
             with open (path, "rb") as file:
                 data = file.read()
             cipher = AES.new(key, AES.MODE_CFB, iv=iv)
+            # ciphering and writing
             ciphered_data = cipher.encrypt(data)
             with open(path, "wb") as file:
                 file.write(b"AES")
@@ -187,18 +193,27 @@ class Ciphers:
                 file.write(salt)
                 file.write(key_signature)
                 file.write(ciphered_data)
-            self.log("File : {} was encrypted at {}.".format(path, str(dt.datetime.utcnow)))
             return 0
+        # encryption for directory.
         elif os.path.isdir(path) is True:
+            # looping through files in dir
             for root, dirs, files in os.walk(path):
                 for file in files:
+                    # checking if each file is suitable for encryption
                     file_name = os.path.join(root, file)
                     return_code = self.check_path_validity(file_name, decrypting=False, type_='AES')
                     if return_code != 0:
                         continue
+                    salt = os.urandom(32)
+                    iv = os.urandom(16)
+                    key_and_salt = self.generate_symmetric_key(salt=None)
+                    key = key_and_salt[0]; salt = key_and_salt[1]
+                    key_hash = hash.sha256(key); key_signature = key_hash.digest()
+                    # getting data and setting cipher
                     with open (file_name, "rb") as file:
                         data = file.read()
                     cipher = AES.new(key, AES.MODE_CFB, iv=iv)
+                    # ciphering and writing.
                     ciphered_data = cipher.encrypt(data)
                     with open(file_name, "wb") as file:
                         file.write(self.marker)
@@ -206,7 +221,6 @@ class Ciphers:
                         file.write(salt)
                         file.write(key_signature)
                         file.write(ciphered_data)
-            self.log("Folder : {} was encrypted at {}.".format(path, str(dt.datetime.utcnow)))
             return 0
 
 
@@ -227,10 +241,13 @@ class Ciphers:
             7: File was not encrypted.
             8: File was encrypted using a different alogorithm.
         """
-        return_code = self.check_path_validity(path, decrypting=True, type_="AES")
-        if return_code != 0:
-            return return_code
+        # decryption for single file
         if os.path.isfile(path) is True:
+            # checking if file is suitable
+            return_code = self.check_path_validity(path, decrypting=True, type_="AES")
+            if return_code != 0:
+                return return_code
+                # gathering needed data
             with open (path, "rb") as file:
                 file.read(3)
                 file.read(14)
@@ -238,42 +255,49 @@ class Ciphers:
                 salt = file.read(32)
                 file_signature = file.read(32)
                 ciphered_data = file.read()
-            key = PBKDF2(self.password, salt, dkLen=32)
+                # building key and key hash, then comparing key hash to file signature
+            key = self.generate_symmetric_key(salt=salt)
             key_hash = hash.sha256(key); key_signature = key_hash.digest()
             if file_signature != key_signature:
                 return 6
+            # setting cipher and decrypting the data
             cipher = AES.new(key, AES.MODE_CFB, iv=iv)
             original_data = cipher.decrypt(ciphered_data)
+            # writing
             with open(path, "wb") as file:
                 file.write(original_data)
             return 0
+        # directory decryption
         elif os.path.isdir(path) is True:
+            # looping through files
             for root, dirs, files in os.walk(path):
                 for file in files:
+                    # checking if file is suitable
                     file_name = os.path.join(root, file)
                     return_code = self.check_path_validity(file_name, decrypting=True)
                     if return_code != 0:
                         continue
+                    # gathering needed data
                     with open (file_name, "rb") as file:
                         file.read(14)
                         iv = file.read(16)
                         salt = file.read(32)
                         file_signature = file.read(32)
                         ciphered_data = file.read()
-                    key = PBKDF2(self.password, salt, dkLen=32)
+                    # building key/key hash and comparing to file signature
+                    key = self.generate_symmetric_key(salt=salt)
                     key_hash = hash.sha256(key); key_signature = key_hash.digest()
                     if key_signature != file_signature:
                         continue
+                    # building the cipher and decrypting the data
                     cipher = AES.new(key, AES.MODE_CFB, iv=iv)
                     original_data = cipher.decrypt(ciphered_data)
+                    # decrypting
                     with open (file_name, "wb") as file:
                         file.write(original_data)
             return 0
         
 
-        self.log()
-        pass
-
 
     # Blowfish functions
 
@@ -282,17 +306,22 @@ class Ciphers:
         """
         A method for encrypting a file using the Blowfish encryption algorithm.
         """
-        return_code = self.check_path_validity(path, decrypting=False, type_="BLO")
-        if return_code != 0:
-            return return_code
-        iv = os.urandom(8)
-        keySalt = self.generate_symmetric_key(salt=None)
-        key = keySalt[0]; salt = keySalt[1]
-        key_hash = hash.sha256(key) ; key_signature = key_hash.hexdigest()
+        # file encryption
         if os.path.isfile(path) is True:
+            # checking if file is suitable
+            return_code = self.check_path_validity(path, decrypting=False, type_="BLO")
+            if return_code != 0:
+                return return_code
+            # generating a key, salt, and key signature
+            key_and_salt = self.generate_symmetric_key(salt=None)
+            key = key_and_salt[0]; salt = key_and_salt[1]
+            key_hash = hash.sha256(key); key_signature = key_hash.digest()
+            iv = os.urandom(8) # generating IV (blowfish only takes 8)
+            # getting data and setting the cipher
             with open (path, "rb") as file:
                 data = file.read()
             cipher = Blowfish.new(key, Blowfish.MODE_CFB, iv=iv)
+            # encrypting the data and writing.
             ciphered_data = cipher.encrypt(data)
             with open (path, "wb") as file:
                 file.write(b"BLO")
@@ -301,17 +330,30 @@ class Ciphers:
                 file.write(salt)
                 file.write(key_signature)
                 file.write(ciphered_data)
+            return 0
+        # directory encryption.
         elif os.path.isdir(path) is True:
+            # looping through files in dir
             for root, dirs, files in os.walk(path):
                 for file in files:
+                    # checking if files are suitable
                     file_name = os.path.join(root, file)
                     return_code = self.check_path_validity(path, decrypting=False, type_="BLO")
                     if return_code != 0:
                         continue
+                    # getting data from file
                     with open(file_name, "rb") as file:
                         data = file.read()
+                    # generating a key and building a key signature
+                    key_and_salt = self.generate_symmetric_key(salt=None)
+                    key = key_and_salt[0]
+                    salt = key_and_salt[1]
+                    key_hash = hash.sha256(key); key_signature = key_hash.digest()
+                    iv = os.urandom(8) # IV for cipher
+                    # setting cipher and encrypting data
                     cipher = Blowfish.new(key, Blowfish.MODE_CFB, iv=iv)
                     ciphered_data = cipher.encrypt(data)
+                    # writing
                     with open(file_name, "rb") as file:
                         file.write(b"BLO")
                         file.write(self.marker)
@@ -322,10 +364,16 @@ class Ciphers:
 
 
     def BLOdecrypt_file(self, path=str):
-        return_code = self.check_path_validity(path, decrypting=True, type_="BLO")
-        if return_code != 0:
-            return return_code
+        """
+        method for decrypting a file encrypted with the Blowfish encryption alogrithm
+        """
+        # file decryption
         if os.path.isfile(path) is True:
+            # checking if file is suitable
+            return_code = self.check_path_validity(path, decrypting=True, type_="BLO")
+            if return_code != 0:
+                return return_code
+            # getting needed data
             with open (path, "rb") as file:
                 file.read(3)
                 file.read(14)
@@ -333,21 +381,29 @@ class Ciphers:
                 salt = file.read(32)
                 file_signature = file.read(32)
                 ciphered_data = file.read()
-                key = self.generate_symmetric_key(salt=salt)
-                key_hash = hash.sha256(key); key_signature = key_hash.hexdigest()
-                if key_signature != file_signature:
-                    return 6
-                cipher = Blowfish.new(key, Blowfish.MODE_CFB, iv=iv)
-                original_data = cipher.decrypt(ciphered_data)
-                with open (path, 'wb') as file:
-                    file.write(original_data)
+                # rebuilding the key and getting its signature
+            key = self.generate_symmetric_key(salt=salt)
+            key_hash = hash.sha256(key); key_signature = key_hash.hexdigest()
+            if key_signature != file_signature:
+                return 6
+            # setting cipher and decrypting data
+            cipher = Blowfish.new(key, Blowfish.MODE_CFB, iv=iv)
+            # writing
+            original_data = cipher.decrypt(ciphered_data)
+            with open (path, 'wb') as file:
+                file.write(original_data)
+            return 0
+        # directory decryption
         elif os.path.isdir(path) is True:
+            # looping through files
             for root, dirs, files in os.walk(path):
                 for file in files:
+                    # checking if file is suitable
                     file_name = os.path.join(root, file)
                     return_code = self.check_path_validity(file_name, decrypting=True, type_="BLO")
                     if return_code != 0:
                         continue
+                    # getting data
                     with open (file_name) as file:
                         file.read(3)
                         file.read(14)
@@ -355,11 +411,18 @@ class Ciphers:
                         salt = file.read(32)
                         file_signature = file.read(32)
                         ciphered_data = file.read()
+                    # building key and key signature
                     key = self.generate_symmetric_key(salt)
                     key_hash = hash.sha256(key); key_signature = key_hash.hexdigest()
                     if key_signature != file_signature:
                         continue
+                    # setting the cipher and decrypting
                     cipher = Blowfish.new(key, Blowfish.MODE_CFB, iv=iv)
                     original_data = cipher.decrypt(ciphered_data)
+                    # writing the data
                     with open (file_name, "wb") as file:
-                        file.write(original_data)
\ No newline at end of file
+                        file.write(original_data)
+
+
+
+    
\ No newline at end of file
